@@ -55,6 +55,8 @@ def test_it_can_set_a_remote_property(mcl):
     assert apt.settable_property == 'ApAntMent'
     apt.settable_property = 'ApSetMent'
     mcl.save(apt)
+    assert not inspect(apt).dirty
+    mcl.registry = {}
     assert mcl.Apartment.query.one().settable_property == 'ApSetMent'
 
 
@@ -67,6 +69,7 @@ def test_it_casts_attribute_types_correctly_when_not_marshalling_from_json(
         "date": date,
         "dt": datetime,
         "json": dict,
+        "boolean": bool
     }
     for key, type_ in expected_types.items():
         assert type(getattr(mt, key)) == type_
